@@ -1,33 +1,37 @@
-define(
-        ['jquery', 'underscore', 'underscore.string', 'pgadmin',
-        'pgadmin.browser', 'alertify', 'pgadmin.browser.collection'],
-function($, _, S, pgAdmin, pgBrowser, Alertify) {
+define('pgadmin.node.foreign_key', [
+  'sources/gettext', 'sources/url_for', 'jquery', 'underscore',
+  'underscore.string', 'pgadmin', 'pgadmin.browser', 'alertify',
+  'sources/alerts/alertify_wrapper',
+
+  'pgadmin.browser.collection'
+], function(gettext, url_for, $, _, S, pgAdmin, pgBrowser, Alertify, AlertifyWrapper) {
 
   var formatNode = function(opt) {
-    if (!opt.id) {
-      return opt.text;
-    }
+        if (!opt.id) {
+          return opt.text;
+        }
 
-    var optimage = $(opt.element).data('image');
+        var optimage = $(opt.element).data('image');
 
-    if(!optimage){
-      return opt.text;
-    } else {
-      return $(
-          '<span><span class="wcTabIcon ' + optimage + '"/>' + opt.text + '</span>'
+        if(!optimage) {
+          return opt.text;
+        } else {
+          return $(
+            '<span><span class="wcTabIcon ' + optimage + '"/>' + opt.text + '</span>'
           );
-    }
-  },
-      headerSelectControlTemplate =  _.template([
-                              '<div class="<%=Backform.controlsClassName%> <%=extraClasses.join(\' \')%>">',
-                              '  <select class="pgadmin-node-select form-control" name="<%=name%>" style="width:100%;" value="<%-value%>" <%=disabled ? "disabled" : ""%> <%=required ? "required" : ""%> >',
-                              '    <%=select2.first_empty ? " <option></option>" : ""%>',
-                              '    <% for (var i=0; i < options.length; i++) { %>',
-                              '    <% var option = options[i]; %>',
-                              '    <option <% if (option.image) { %> data-image=<%= option.image %> <% } %> value=<%= formatter.fromRaw(option.value) %> <%=option.value === rawValue ? "selected=\'selected\'" : "" %>><%-option.label%></option>',
-                              '    <% } %>',
-                              '  </select>',
-                              '</div>'].join("\n"));
+        }
+      },
+      headerSelectControlTemplate = _.template([
+        '<div class="<%=Backform.controlsClassName%> <%=extraClasses.join(\' \')%>">',
+        '  <select class="pgadmin-node-select form-control" name="<%=name%>" style="width:100%;" value="<%-value%>" <%=disabled ? "disabled" : ""%> <%=required ? "required" : ""%> >',
+        '    <%=select2.first_empty ? " <option></option>" : ""%>',
+        '    <% for (var i=0; i < options.length; i++) { %>',
+        '    <% var option = options[i]; %>',
+        '    <option <% if (option.image) { %> data-image=<%= option.image %> <% } %> value=<%= formatter.fromRaw(option.value) %> <%=option.value === rawValue ? "selected=\'selected\'" : "" %>><%-option.label%></option>',
+        '    <% } %>',
+        '  </select>',
+        '</div>'].join("\n")
+      );
 
   var ForeignKeyColumnModel = pgBrowser.Node.Model.extend({
     defaults: {
@@ -135,7 +139,7 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
           }),
           select2: {
             allowClear: false, width: 'style',
-            placeholder: '{{ _('Select column') }}',
+            placeholder: gettext('Select column'),
             first_empty: !_.isUndefined(self.model.get('oid'))
           },
           version_compatible: self.field.get('version_compatible'),
@@ -240,7 +244,7 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
           select2: {
             allowClear: false,
             width: "style",
-            placeholder: '{{ _('Select column') }}',
+            placeholder: gettext('Select column'),
             templateResult: formatNode,
             templateSelection: formatNode
           },
@@ -323,9 +327,9 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
         '</div>',].join("\n")
 
       _.extend(data, {
-        column_label: '{{ _('Local column') }}',
-        references_label: '{{ _('References') }}',
-        referenced_label: '{{ _('Referencing') }}'
+        column_label: gettext('Local column'),
+        references_label: gettext('References'),
+        referenced_label: gettext('Referencing')
       });
 
       var self = this,
@@ -598,15 +602,16 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
   // Extend the browser's node class for foreign key node
   if (!pgBrowser.Nodes['foreign_key']) {
     pgAdmin.Browser.Nodes['foreign_key'] = pgBrowser.Node.extend({
+      getTreeNodeHierarchy: pgBrowser.tableChildTreeNodeHierarchy,
       type: 'foreign_key',
-      label: '{{ _('Foreign key') }}',
+      label: gettext('Foreign key'),
       collection_type: 'coll-constraints',
       sqlAlterHelp: 'ddl-alter.html',
       sqlCreateHelp: 'ddl-constraints.html',
-      dialogHelp: '{{ url_for('help.static', filename='foreign_key_dialog.html') }}',
+      dialogHelp: url_for('help.static', {'filename': 'foreign_key_dialog.html'}),
       hasSQL: true,
       hasDepends: false,
-      parent_type: 'table',
+      parent_type: ['table','partition'],
       canDrop: true,
       canDropCascade: true,
       hasDepends: true,
@@ -620,13 +625,13 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
         pgBrowser.add_menus([{
           name: 'create_foreign_key_on_coll', node: 'coll-constraints', module: this,
           applies: ['object', 'context'], callback: 'show_obj_properties',
-          category: 'create', priority: 4, label: '{{ _('Foreign key...') }}',
+          category: 'create', priority: 4, label: gettext('Foreign key...'),
           icon: 'wcTabIcon icon-foreign_key', data: {action: 'create', check: true},
           enable: 'canCreate'
         },{
           name: 'validate_foreign_key', node: 'foreign_key', module: this,
           applies: ['object', 'context'], callback: 'validate_foreign_key',
-          category: 'validate', priority: 4, label: '{{ _('Validate foreign key') }}',
+          category: 'validate', priority: 4, label: gettext('Validate foreign key'),
           icon: 'fa fa-link', enable : 'is_not_valid'
         }
         ]);
@@ -651,7 +656,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             type:'GET',
             success: function(res) {
               if (res.success == 1) {
-                Alertify.success("{{ _('" + res.info + "') }}");
+                var alertifyWrapper = new AlertifyWrapper();
+                alertifyWrapper.success(res.info);
                 t.removeIcon(i);
                 data.valid = true;
                 data.icon = 'icon-foreign_key';
@@ -664,8 +670,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
               try {
                 var err = $.parseJSON(xhr.responseText);
                 if (err.success == 0) {
-                  msg = S('{{ _(' + err.errormsg + ')}}').value();
-                  Alertify.error("{{ _('" + err.errormsg + "') }}");
+                  var alertifyWrapper = new AlertifyWrapper();
+                  alertifyWrapper.error(err.errormsg);
                 }
               } catch (e) {}
               t.unload(i);
@@ -701,14 +707,14 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
         },
         // Define the schema for the foreign key node
         schema: [{
-          id: 'name', label: '{{ _('Name') }}', type: 'text',
+          id: 'name', label: gettext('Name'), type: 'text',
           mode: ['properties', 'create', 'edit'], editable:true,
           headerCell: Backgrid.Extension.CustomHeaderCell, cellHeaderClasses: 'width_percent_50'
         },{
-          id: 'oid', label:'{{ _('OID') }}', cell: 'string',
+          id: 'oid', label: gettext('OID'), cell: 'string',
           type: 'text' , mode: ['properties']
         },{
-          id: 'comment', label:'{{ _('Comment') }}', cell: 'string',
+          id: 'comment', label: gettext('Comment'), cell: 'string',
           type: 'multiline', mode: ['properties', 'create', 'edit'],
           deps:['name'], disabled:function(m) {
             var name = m.get('name');
@@ -723,8 +729,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             }
           }
         },{
-          id: 'condeferrable', label: '{{ _('Deferrable?') }}',
-          type: 'switch', group: '{{ _('Definition') }}',
+          id: 'condeferrable', label: gettext('Deferrable?'),
+          type: 'switch', group: gettext('Definition'),
           disabled: function(m) {
             // If we are in table edit mode then
             if (_.has(m, 'handler') && !_.isUndefined(m.handler)) {
@@ -736,8 +742,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return !m.isNew();
           }
         },{
-          id: 'condeferred', label: '{{ _('Deferred?') }}',
-          type: 'switch', group: '{{ _('Definition') }}',
+          id: 'condeferred', label: gettext('Deferred?'),
+          type: 'switch', group: gettext('Definition'),
           deps: ['condeferrable'],
           disabled: function(m) {
             // If we are in table edit mode then
@@ -760,8 +766,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             }
           }
         },{
-          id: 'confmatchtype', label: '{{ _('Match type') }}',
-          type: 'switch', group: '{{ _('Definition') }}',
+          id: 'confmatchtype', label: gettext('Match type'),
+          type: 'switch', group: gettext('Definition'),
           options: {
             onText: 'FULL',
             offText: 'SIMPLE',
@@ -776,11 +782,11 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return !m.isNew();
           }
         },{
-          id: 'convalidated', label: "{{ _("Validated?") }}",
-          type: 'switch', group: '{{ _('Definition') }}',
+          id: 'convalidated', label: gettext("Validated?"),
+          type: 'switch', group: gettext('Definition'),
           options: {
-            onText: 'Yes',
-            offText: 'No'
+            onText: gettext('Yes'),
+            offText: gettext('No')
           },disabled: function(m) {
             // If we are in table edit mode then
             if (_.has(m, 'handler') && !_.isUndefined(m.handler)) {
@@ -792,12 +798,12 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return !(m.isNew() || m.get("convalidated"));
           }
         },{
-          id: 'autoindex', label: '{{ _('Auto FK index?') }}',
-          type: 'switch', group: '{{ _('Definition') }}',
+          id: 'autoindex', label: gettext('Auto FK index?'),
+          type: 'switch', group: gettext('Definition'),
           deps: ['name', 'hasindex'],
           options: {
-            onText: 'Yes',
-            offText: 'No',
+            onText: gettext('Yes'),
+            offText: gettext('No')
           },disabled: function(m) {
             var index = m.get('coveringindex'),
                 autoindex = m.get('autoindex'),
@@ -840,8 +846,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             }
           }
         },{
-          id: 'coveringindex', label: '{{ _('Covering index') }}', type: 'text',
-          mode: ['properties', 'create', 'edit'], group: '{{ _('Definition') }}',
+          id: 'coveringindex', label: gettext('Covering index'), type: 'text',
+          mode: ['properties', 'create', 'edit'], group: gettext('Definition'),
           deps:['autoindex', 'hasindex'],
           disabled: function(m) {
             var index = m.get('coveringindex'),
@@ -886,8 +892,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return setIndexName();
           }
         },{
-          id: 'columns', label: '{{ _('Columns') }}',
-          type: 'collection', group: '{{ _('Columns') }}', disabled: false,
+          id: 'columns', label: gettext('Columns'),
+          type: 'collection', group: gettext('Columns'), disabled: false,
           node: 'foreign_key', editable: false, headerCell: Backgrid.Extension.CustomHeaderCell,
           cellHeaderClasses: 'width_percent_50',
           cell: Backgrid.StringCell.extend({
@@ -994,8 +1000,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return !m.isNew();
             }
         },{
-          id: 'confupdtype', label:'{{ _('On update') }}',
-          type:"select2", group: '{{ _('Action') }}', mode: ['edit','create'],
+          id: 'confupdtype', label: gettext('On update'),
+          type:"select2", group: gettext('Action'), mode: ['edit','create'],
           select2:{width:"50%", allowClear: false},
           options: [
             {label: "NO ACTION", value: "a"},
@@ -1014,8 +1020,8 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
             return !m.isNew();
           }
         },{
-          id: 'confdeltype', label:'{{ _('On delete') }}',
-          type:"select2", group: '{{ _('Action') }}', mode: ['edit','create'],
+          id: 'confdeltype', label: gettext('On delete'),
+          type:"select2", group: gettext('Action'), mode: ['edit','create'],
           select2:{width:"50%", allowClear: false},
           options: [
             {label: "NO ACTION", value: "a"},
@@ -1040,7 +1046,7 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
 
           var columns = this.get('columns');
           if ((_.isUndefined(columns) || _.isNull(columns) || columns.length < 1)) {
-            var msg = '{{ _('Please specify columns for Foreign key.') }}';
+            var msg = gettext('Please specify columns for Foreign key.');
             this.errorModel.set('columns', msg);
             return msg;
           }
@@ -1049,7 +1055,7 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
               autoindex = this.get('autoindex');
           if (autoindex && (_.isUndefined(coveringindex) || _.isNull(coveringindex) ||
             String(coveringindex).replace(/^\s+|\s+$/g, '') == '')) {
-            var msg = '{{ _('Please specify covering index name.') }}';
+            var msg = gettext('Please specify covering index name.');
             this.errorModel.set('coveringindex', msg);
             return msg;
           }
@@ -1063,12 +1069,22 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
           if (data && data.check == false)
             return true;
 
-          var t = pgBrowser.tree, i = item, d = itemData, parents = [];
+          var t = pgBrowser.tree, i = item, d = itemData, parents = [],
+            immediate_parent_table_found = false,
+            is_immediate_parent_table_partitioned = false;
           // To iterate over tree to check parent node
           while (i) {
+            // If table is partitioned table then return false
+            if (!immediate_parent_table_found && (d._type == 'table' || d._type == 'partition')) {
+              immediate_parent_table_found = true;
+              if ('is_partitioned' in d && d.is_partitioned) {
+                is_immediate_parent_table_partitioned = true;
+              }
+            }
+
             // If it is schema then allow user to c reate table
             if (_.indexOf(['schema'], d._type) > -1)
-              return true;
+              return !is_immediate_parent_table_partitioned;
             parents.push(d._type);
             i = t.hasParent(i) ? t.parent(i) : null;
             d = i ? t.itemData(i) : null;
@@ -1077,7 +1093,7 @@ function($, _, S, pgAdmin, pgBrowser, Alertify) {
           if (_.indexOf(parents, 'catalog') > -1) {
             return false;
           } else {
-            return true;
+            return !is_immediate_parent_table_partitioned;
           }
       }
     });
